@@ -1,16 +1,16 @@
 /* bjb-app-menu.c
  * Copyright (C) Pierre-Yves LUYTEN 2011 <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.*/
 
@@ -126,7 +126,11 @@ help_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GError *error = NULL;
-  gtk_show_uri (NULL, "help:bijiben", gtk_get_current_event_time (), &error);
+
+  gtk_show_uri_on_window (gtk_application_get_active_window (user_data),
+                          "help:bijiben",
+                          GDK_CURRENT_TIME,
+                          &error);
 
   if (error)
   {
@@ -157,7 +161,7 @@ static GActionEntry app_entries[] = {
 };
 
 
-void bjb_app_menu_set(GApplication *application) 
+void bjb_app_menu_set(GApplication *application)
 {
   GtkBuilder *builder;
 
@@ -169,7 +173,7 @@ void bjb_app_menu_set(GApplication *application)
   builder = gtk_builder_new ();
   gtk_builder_add_from_resource (builder, "/org/gnome/bijiben/app-menu.ui", NULL);
 
-  gtk_application_set_app_menu (GTK_APPLICATION (application), 
+  gtk_application_set_app_menu (GTK_APPLICATION (application),
                                 G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu")));
   g_object_unref (builder);
 }
