@@ -85,7 +85,7 @@ G_DEFINE_TYPE (BjbImportDialog, bjb_import_dialog, GTK_TYPE_DIALOG)
 
 
 static ImportDialogChild *
-import_dialog_child_new ()
+import_dialog_child_new (void)
 {
   ImportDialogChild *retval = g_slice_new (ImportDialogChild);
 
@@ -112,7 +112,7 @@ import_dialog_child_free (ImportDialogChild *child)
  * might use app_info here */
 
 static GdkPixbuf *
-get_app_icon (gchar *app_name)
+get_app_icon (const gchar *app_name)
 {
   gint i;
   GdkPixbuf *retval= NULL;
@@ -154,7 +154,7 @@ application_quark (void)
 
 
 static GtkWidget *
-child_toggle_new ()
+child_toggle_new (void)
 {
   GtkWidget *w;
 
@@ -333,8 +333,8 @@ add_custom (BjbImportDialog *self)
 
 
 static ImportDialogChild *
-add_application (gchar *app,
-                 gchar *visible_label,
+add_application (const gchar *app,
+                 const gchar *visible_label,
                  gchar *location)
 {
   GtkWidget *box, *w;
@@ -382,8 +382,6 @@ add_application (gchar *app,
 static void
 bjb_import_dialog_constructed (GObject *obj)
 {
-  G_OBJECT_CLASS(bjb_import_dialog_parent_class)->constructed(obj);
-
   GtkWidget *area, *label_box, *label, *frame;
   gchar *path;
   GList *windows;
@@ -393,6 +391,8 @@ bjb_import_dialog_constructed (GObject *obj)
   GtkWindow              *win     = GTK_WINDOW (obj);
   BjbImportDialogPrivate *priv    = self->priv;
 
+  G_OBJECT_CLASS(bjb_import_dialog_parent_class)->constructed(obj);
+
   /* Don't finalize locations with HashTable
    * They belong to qdata in gtkwidgets */
 
