@@ -15,6 +15,8 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <libgd/gd.h>
 
@@ -1024,7 +1026,7 @@ populate_main_toolbar(BjbMainToolbar *self)
 
 
   /* Simply clear then populate */
-  if (to_be != priv->type)
+  if (to_be != priv->type || view_type == BJB_WINDOW_BASE_ARCHIVE_VIEW)
   {
     /* If we leave a note view */
     if (priv->type == BJB_TOOLBAR_NOTE_VIEW)
@@ -1131,6 +1133,7 @@ bjb_main_toolbar_get_property (GObject     *object,
   {
     case PROP_PARENT:
       g_value_set_object (value, self->priv->parent);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
       break;
