@@ -1,18 +1,18 @@
 /*
  * biji-import-provider.h
- * 
+ *
  * Copyright 2013 Pierre-Yves Luyten <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -66,8 +66,8 @@ GType                   biji_import_provider_get_type             (void);
 
 
 BijiProvider           *biji_import_provider_new                  (BijiManager *manager,
-                                                                   gchar *target_provider,
-                                                                   gchar *uri);
+                                                                   const gchar *target_provider,
+                                                                   const gchar *uri);
 
 
 G_END_DECLS
