@@ -1,16 +1,16 @@
 /* bjb-own-cloud-note.c
  * Copyright (C) Pierre-Yves LUYTEN 2013 <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -54,7 +54,7 @@ G_DEFINE_TYPE (BijiOwnCloudNote, biji_own_cloud_note, BIJI_TYPE_NOTE_OBJ)
 
 
 
-const gchar *
+static const gchar *
 ocloud_note_get_place (BijiItem *local)
 {
   BijiOwnCloudNote *self;
@@ -110,7 +110,7 @@ ocloud_note_get_html (BijiNoteObj *note)
 /* We don't put any html to note. We do not need this */
 static void
 ocloud_note_set_html (BijiNoteObj *note,
-                      gchar *html)
+                      const gchar *html)
 {
 
 }
@@ -154,7 +154,7 @@ ocloud_note_ensure_ressource (BijiNoteObj *note)
 
 /* TODO: propagate error if any
  * through generic provider -> manager */
-void
+static void
 on_content_replaced  (GObject *source_object,
                       GAsyncResult *res,
                       gpointer user_data)
