@@ -1,17 +1,17 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
 /* biji-own-cloud-provider.c
  * Copyright (C) Pierre-Yves LUYTEN 2013 <py@luyten.fr>
- * 
+ *
  * bijiben is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * bijiben is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -131,12 +131,17 @@ biji_own_cloud_provider_finalize (GObject *object)
   if (self->priv->path != NULL)
     g_free (self->priv->path);
 
-  g_object_unref (self->priv->account);
-  g_object_unref (self->priv->object);
-  g_object_unref (self->priv->info.icon);
-  g_object_unref (self->priv->folder);
+  g_clear_object (&self->priv->account);
+  g_clear_object (&self->priv->object);
+  g_clear_object (&self->priv->info.icon);
+  g_clear_object (&self->priv->folder);
 
   g_clear_pointer (&self->priv->info.name, g_free);
+  g_clear_pointer (&self->priv->info.datasource, g_free);
+
+  g_queue_free_full (self->priv->queue, g_object_unref);
+  g_hash_table_unref (self->priv->notes);
+  g_hash_table_unref (self->priv->tracker);
 
   G_OBJECT_CLASS (biji_own_cloud_provider_parent_class)->finalize (object);
 }
@@ -790,9 +795,11 @@ biji_own_cloud_provider_constructed (GObject *obj)
     {
       priv->info.icon = gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_INVALID);
       gtk_image_set_pixel_size (GTK_IMAGE (priv->info.icon), 48);
-      g_object_ref (priv->info.icon);
+      g_object_ref_sink (priv->info.icon);
     }
 
+    g_object_unref (icon);
+
     owncloudclient = g_build_filename (
         g_get_home_dir (),
         ".local/share/data/ownCloud/folders/ownCloud",
@@ -806,6 +813,8 @@ biji_own_cloud_provider_constructed (GObject *obj)
     else
 			get_mount (self);
 
+    g_object_unref (client);
+
     return;
   }
 
@@ -893,9 +902,9 @@ own_cloud_get_info       (BijiProvider *provider)
  * things will go right.
  * Promise. */
 
-BijiNoteObj *
-own_cloud_create_note         (BijiProvider *provider,
-                               gchar        *str)
+static BijiNoteObj *
+own_cloud_create_note (BijiProvider *provider,
+                       const gchar  *str)
 {
   BijiInfoSet info;
   BijiOwnCloudProvider *self;
@@ -904,7 +913,7 @@ own_cloud_create_note         (BijiProvider *provider,
   info.url = NULL;
   info.title = NULL;
   info.mtime = g_get_real_time ();
-  info.content = "";
+  info.content = (gchar *) "";
   info.created = g_get_real_time ();
 
   return biji_own_cloud_note_new_from_info (
@@ -919,12 +928,12 @@ own_cloud_create_note         (BijiProvider *provider,
 /* This is a dummy func. we can create a note with extra args
  * but can't use path, nor color, nor html. */
 
-BijiNoteObj *
-own_cloud_create_full (BijiProvider *provider,
-                       gchar        *suggested_path,
-                       BijiInfoSet  *info,
-                       gchar        *html,
-                       GdkRGBA      *color)
+static BijiNoteObj *
+own_cloud_create_full (BijiProvider  *provider,
+                       const gchar   *suggested_path,
+                       BijiInfoSet   *info,
+                       const gchar   *html,
+                       const GdkRGBA *color)
 {
   BijiOwnCloudProvider *self;
   BijiNoteObj *retval;
